Struct HttpMessage
Source #[repr(C)]
pub struct HttpMessage {
pub data: HttpRequestOrResponse,
pub header_count: usize,
pub header: *mut HttpHeader,
pub body_length: usize,
pub body: *mut c_void,
}
body_length: usizebody: *mut c_void
Formats the value using the given formatter.
Read more
Returns the “default value” for a type.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.